==> gpiozero_1.6.2.orig.tar.gz: gpiozero-1.6.2/gpiozero/__init__.py <==
# vim: set fileencoding=utf-8:
#
# GPIO Zero: a library for controlling the Raspberry Pi's GPIO pins
#
# Copyright (c) 2015-2021 Dave Jones <dave@waveform.org.uk>
# Copyright (c) 2015-2021 Ben Nuttall <ben@bennuttall.com>
# Copyright (c) 2019 tuftii <3215045+tuftii@users.noreply.github.com>
# Copyright (c) 2019 Jeevan M R <14.jeevan@gmail.com>
# Copyright (c) 2019 ForToffee <ForToffee@users.noreply.github.com>
# Copyright (c) 2018 Claire Pollard <claire.r.pollard@gmail.com>
# Copyright (c) 2016 pcopa <scheltovandoorn@gmail.com>
# Copyright (c) 2016 Ian Harcombe <ian.harcombe@gmail.com>
# Copyright (c) 2016 Andrew Scheller <github@loowis.durge.org>
# Copyright (c) 2016 Andrew Scheller <lurch@durge.org>
# Copyright (c) 2015 Philip Howard <phil@gadgetoid.com>
#
# SPDX-License-Identifier: BSD-3-Clause

from __future__ import (
    unicode_literals,
    print_function,
    absolute_import,
    division,
)

from .pins import (
    Factory,
    Pin,
    SPI,
)
from .pins.data import (
    PiBoardInfo,
    HeaderInfo,
    PinInfo,
    pi_info,
)
# Yes, import * is naughty, but exc imports nothing else so there's no cross
# contamination here ... and besides, have you *seen* the list lately?!
from .exc import *
from .devices import (
    Device,
    GPIODevice,
    CompositeDevice,
)
from .mixins import (
    SharedMixin,
    SourceMixin,
    ValuesMixin,
    EventsMixin,
    event,
    HoldMixin,
)
from .input_devices import (
    InputDevice,
    DigitalInputDevice,
    SmoothedInputDevice,
    Button,
    LineSensor,
    MotionSensor,
    LightSensor,
    DistanceSensor,
    RotaryEncoder,
)
from .spi_devices import (
    SPIDevice,
    AnalogInputDevice,
    MCP3001,
    MCP3002,
    MCP3004,
    MCP3008,
    MCP3201,
    MCP3202,
    MCP3204,
    MCP3208,
    MCP3301,
    MCP3302,
    MCP3304,
)
from .output_devices import (
    OutputDevice,
    DigitalOutputDevice,
    PWMOutputDevice,
    PWMLED,
    LED,
    Buzzer,
    Motor,
    PhaseEnableMotor,
    Servo,
    AngularServo,
    RGBLED,
    TonalBuzzer,
)
from .boards import (
    CompositeOutputDevice,
    ButtonBoard,
    LEDCollection,
    LEDBoard,
    LEDBarGraph,
    LEDCharDisplay,
    LEDMultiCharDisplay,
    LEDCharFont,
    LedBorg,
    PiHutXmasTree,
    PiLiter,
    PiLiterBarGraph,
    TrafficLights,
    PiTraffic,
    PiStop,
    StatusZero,
    StatusBoard,
    SnowPi,
    TrafficLightsBuzzer,
    FishDish,
    TrafficHat,
    TrafficpHat,
    Robot,
    RyanteckRobot,
    CamJamKitRobot,
    PhaseEnableRobot,
    PololuDRV8835Robot,
    Energenie,
    PumpkinPi,
    JamHat,
    Pibrella,
)
from .internal_devices import (
    InternalDevice,
    PolledInternalDevice,
    PingServer,
    CPUTemperature,
    LoadAverage,
    TimeOfDay,
    DiskUsage,
)

==> gpiozero_2.0.1.orig.tar.gz: gpiozero-2.0.1/gpiozero/__init__.py <==
# vim: set fileencoding=utf-8:
#
# GPIO Zero: a library for controlling the Raspberry Pi's GPIO pins
#
# Copyright (c) 2015-2023 Dave Jones <dave@waveform.org.uk>
# Copyright (c) 2015-2021 Ben Nuttall <ben@bennuttall.com>
# Copyright (c) 2019 tuftii <3215045+tuftii@users.noreply.github.com>
# Copyright (c) 2019 Jeevan M R <14.jeevan@gmail.com>
# Copyright (c) 2019 ForToffee <ForToffee@users.noreply.github.com>
# Copyright (c) 2018 Claire Pollard <claire.r.pollard@gmail.com>
# Copyright (c) 2016 pcopa <scheltovandoorn@gmail.com>
# Copyright (c) 2016 Ian Harcombe <ian.harcombe@gmail.com>
# Copyright (c) 2016 Andrew Scheller <github@loowis.durge.org>
# Copyright (c) 2016 Andrew Scheller <lurch@durge.org>
# Copyright (c) 2015 Philip Howard <phil@gadgetoid.com>
#
# SPDX-License-Identifier: BSD-3-Clause

from .pins import (
    Factory,
    Pin,
    SPI,
    BoardInfo,
    HeaderInfo,
    PinInfo,
)
from .pins.pi import (
    PiBoardInfo,
    pi_info,
)
# Yes, import * is naughty, but exc imports nothing else so there's no cross
# contamination here ... and besides, have you *seen* the list lately?!
from .exc import *
from .devices import (
    Device,
    GPIODevice,
    CompositeDevice,
)
from .mixins import (
    SharedMixin,
    SourceMixin,
    ValuesMixin,
    EventsMixin,
    event,
    HoldMixin,
)
from .input_devices import (
    InputDevice,
    DigitalInputDevice,
    SmoothedInputDevice,
    Button,
    LineSensor,
    MotionSensor,
    LightSensor,
    DistanceSensor,
    RotaryEncoder,
)
from .spi_devices import (
    SPIDevice,
    AnalogInputDevice,
    MCP3001,
    MCP3002,
    MCP3004,
    MCP3008,
    MCP3201,
    MCP3202,
    MCP3204,
    MCP3208,
    MCP3301,
    MCP3302,
    MCP3304,
)
from .output_devices import (
    OutputDevice,
    DigitalOutputDevice,
    PWMOutputDevice,
    PWMLED,
    LED,
    Buzzer,
    Motor,
    PhaseEnableMotor,
    Servo,
    AngularServo,
    RGBLED,
    TonalBuzzer,
)
from .boards import (
    CompositeOutputDevice,
    ButtonBoard,
    LEDCollection,
    LEDBoard,
    LEDBarGraph,
    LEDCharDisplay,
    LEDMultiCharDisplay,
    LEDCharFont,
    LedBorg,
    PiHutXmasTree,
    PiLiter,
    PiLiterBarGraph,
    TrafficLights,
    PiTraffic,
    PiStop,
    StatusZero,
    StatusBoard,
    SnowPi,
    TrafficLightsBuzzer,
    FishDish,
    TrafficHat,
    TrafficpHat,
    Robot,
    RyanteckRobot,
    CamJamKitRobot,
    PololuDRV8835Robot,
    PhaseEnableRobot,
    Energenie,
    PumpkinPi,
    JamHat,
    Pibrella,
)
from .internal_devices import (
    InternalDevice,
    PolledInternalDevice,
    PingServer,
    CPUTemperature,
    LoadAverage,
    TimeOfDay,
    DiskUsage,
)
